@@ -70,7 +70,9 @@ public:
   virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
   virtual Type type() const Q_DECL_OVERRIDE { return MusicBrainz; }
   virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
+  virtual bool needsUserAgent() const Q_DECL_OVERRIDE { return true; }
   virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
+  void setLimit(int limit);
 
   /**
    * Returns a widget for modifying the fetcher's config.
